<center>Hi  everyone ,
<marquee> Auther : Simplehacker02 </marquee>
this project only for edeqution perposal 

<mark>apt source only </mark>
<pre>
 apt update
 apt upgrade -y
 apt install python3-pip -y
 pip3 install --upgrade pip
 pip3 install sm02eveldc

 <mark> runing commonds</mark>
 type 
 <mark>sm02eveldc</mark>
     </pre>

###  Auther :  
<mark> simplehacker1, simplehacker01, simplehacker02
### Auther : 
<mark> Simplehacker1 Community Group
### Powered by team member :
### Starting Project date : 09/12/2021
### update date  : 19/12/2021
### version : 1.1 BETA
### About  : evel encoding decoding Script


</center>